/******************************************************************************
 *
 * LPC2129 Demo - uart 'echo' for boards LPC-P2129 and LPC-E2129
 * LPC-P2129 - connect RS232 cable to RS232_ICSP connector on board and open Hyperterminal to baudrate 9600
 * LPC-E2129 - connect USB cable to board and open Hyperterminal to baudrate 9600
 * ----------------------------------------------------------------------------
  *
 */

void Initialize(void);
void feed(void);

void IRQ_Routine (void)   __attribute__ ((interrupt("IRQ")));
void FIQ_Routine (void)   __attribute__ ((interrupt("FIQ")));
void SWI_Routine (void)   __attribute__ ((interrupt("SWI")));
void UNDEF_Routine (void) __attribute__ ((interrupt("UNDEF")));

#include "lpc21xx.h"
//#include "config.h" /* Clock config */
#include "uart.h"

#define BAUD 9600

#define PLOCK 0x400

int main(void) 
{
	unsigned int val, chan;
	unsigned int ch;

	Initialize();	/* init PLL, MAM etc. */

	uart0Init(UART_BAUD(BAUD), UART_8N1, UART_FIFO_8);
		
	while(1) {
		ch=uart0GetchW();
		uart0Putch(ch);
		
	} // while
	
	return 0; /* never reached */
}


void Initialize(void)  {
	
 
	// 				Setting the Phased Lock Loop (PLL)
	//               ----------------------------------
	//
	// Olimex LPC-P2106 has a 14.7456 mhz crystal
	
   
	// Setting Multiplier and Divider values
  	PLLCFG=0x23;
  	feed();  
	// Enabling the PLL */	
	PLLCON=0x1;
	feed();
  
	// Wait for the PLL to lock to set frequency
	while(!(PLLSTAT & PLOCK)) ;
  
	// Connect the PLL as the clock source
	PLLCON=0x3;
	feed();
  
	// Enabling MAM and setting number of clocks used for Flash memory fetch (4 cclks in this case)
	MAMCR=0x2;
	MAMTIM=0x4;
  
	// Setting peripheral Clock (pclk) to System Clock (cclk)
	VPBDIV=0x1;
}


void feed(void)
{
  PLLFEED=0xAA;
  PLLFEED=0x55;
}

/*  Stubs for various interrupts (may be replaced later)  */
/*  ----------------------------------------------------  */

void IRQ_Routine (void) {
	while (1) ;	
}

void FIQ_Routine (void)  {
	while (1) ;	
}


void SWI_Routine (void)  {
	while (1) ;	
}


void UNDEF_Routine (void) {
	while (1) ;	
}
